# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class Client(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'type': 'ClientType',
        'status': 'str',
        'integration_id': 'str',
        'external_id': 'str',
        'last_seen': 'str',
        'linked_at': 'str',
        'display_name': 'str',
        'avatar_url': 'str',
        'info': 'object',
        'raw': 'object'
    }

    attribute_map = {
        'id': 'id',
        'type': 'type',
        'status': 'status',
        'integration_id': 'integrationId',
        'external_id': 'externalId',
        'last_seen': 'lastSeen',
        'linked_at': 'linkedAt',
        'display_name': 'displayName',
        'avatar_url': 'avatarUrl',
        'info': 'info',
        'raw': 'raw'
    }

    nulls = set()

    def __init__(self, id=None, type=None, status=None, integration_id=Undefined(), external_id=Undefined(), last_seen=Undefined(), linked_at=Undefined(), display_name=Undefined(), avatar_url=Undefined(), info=Undefined(), raw=Undefined(), local_vars_configuration=None):  # noqa: E501
        """Client - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._type = None
        self._status = None
        self._integration_id = None
        self._external_id = None
        self._last_seen = None
        self._linked_at = None
        self._display_name = None
        self._avatar_url = None
        self._info = None
        self._raw = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if status is not None:
            self.status = status
        self.integration_id = integration_id
        self.external_id = external_id
        self.last_seen = last_seen
        self.linked_at = linked_at
        self.display_name = display_name
        self.avatar_url = avatar_url
        self.info = info
        self.raw = raw

    @property
    def id(self):
        """Gets the id of this Client.  # noqa: E501

        The unique ID of the client.  # noqa: E501

        :return: The id of this Client.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Client.

        The unique ID of the client.  # noqa: E501

        :param id: The id of this Client.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this Client.  # noqa: E501


        :return: The type of this Client.  # noqa: E501
        :rtype: ClientType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Client.


        :param type: The type of this Client.  # noqa: E501
        :type: ClientType
        """

        self._type = type

    @property
    def status(self):
        """Gets the status of this Client.  # noqa: E501

        The client status. Indicates if the client is able to receive messages or not. Can be pending, inactive, active, or blocked.  # noqa: E501

        :return: The status of this Client.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Client.

        The client status. Indicates if the client is able to receive messages or not. Can be pending, inactive, active, or blocked.  # noqa: E501

        :param status: The status of this Client.  # noqa: E501
        :type: str
        """
        allowed_values = ["active", "blocked", "inactive", "pending"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def integration_id(self):
        """Gets the integration_id of this Client.  # noqa: E501

        The ID of the integration that the client was created for. Unused for clients of type sdk, as they incorporate multiple integrations.  # noqa: E501

        :return: The integration_id of this Client.  # noqa: E501
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this Client.

        The ID of the integration that the client was created for. Unused for clients of type sdk, as they incorporate multiple integrations.  # noqa: E501

        :param integration_id: The integration_id of this Client.  # noqa: E501
        :type: str
        """
        if type(integration_id) is Undefined:
            integration_id = None
            self.nulls.discard("integration_id")
        elif integration_id is None:
            self.nulls.add("integration_id")
        else:
            self.nulls.discard("integration_id")

        self._integration_id = integration_id

    @property
    def external_id(self):
        """Gets the external_id of this Client.  # noqa: E501

        The ID of the user on an external channel. For example, the user’s phone number for Twilio, or their page-scoped user ID for Facebook Messenger. Applies only to non-SDK clients.  # noqa: E501

        :return: The external_id of this Client.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Client.

        The ID of the user on an external channel. For example, the user’s phone number for Twilio, or their page-scoped user ID for Facebook Messenger. Applies only to non-SDK clients.  # noqa: E501

        :param external_id: The external_id of this Client.  # noqa: E501
        :type: str
        """
        if type(external_id) is Undefined:
            external_id = None
            self.nulls.discard("external_id")
        elif external_id is None:
            self.nulls.add("external_id")
        else:
            self.nulls.discard("external_id")

        self._external_id = external_id

    @property
    def last_seen(self):
        """Gets the last_seen of this Client.  # noqa: E501

        A datetime string with the format `YYYY-MM-DDThh:mm:ss.SSSZ` representing the last time the user interacted with this client.  # noqa: E501

        :return: The last_seen of this Client.  # noqa: E501
        :rtype: str
        """
        return self._last_seen

    @last_seen.setter
    def last_seen(self, last_seen):
        """Sets the last_seen of this Client.

        A datetime string with the format `YYYY-MM-DDThh:mm:ss.SSSZ` representing the last time the user interacted with this client.  # noqa: E501

        :param last_seen: The last_seen of this Client.  # noqa: E501
        :type: str
        """
        if type(last_seen) is Undefined:
            last_seen = None
            self.nulls.discard("last_seen")
        elif last_seen is None:
            self.nulls.add("last_seen")
        else:
            self.nulls.discard("last_seen")

        self._last_seen = last_seen

    @property
    def linked_at(self):
        """Gets the linked_at of this Client.  # noqa: E501

        A timestamp signifying when the client was added to the user. Formatted as `YYYY-MM-DDThh:mm:ss.SSSZ`.  # noqa: E501

        :return: The linked_at of this Client.  # noqa: E501
        :rtype: str
        """
        return self._linked_at

    @linked_at.setter
    def linked_at(self, linked_at):
        """Sets the linked_at of this Client.

        A timestamp signifying when the client was added to the user. Formatted as `YYYY-MM-DDThh:mm:ss.SSSZ`.  # noqa: E501

        :param linked_at: The linked_at of this Client.  # noqa: E501
        :type: str
        """
        if type(linked_at) is Undefined:
            linked_at = None
            self.nulls.discard("linked_at")
        elif linked_at is None:
            self.nulls.add("linked_at")
        else:
            self.nulls.discard("linked_at")

        self._linked_at = linked_at

    @property
    def display_name(self):
        """Gets the display_name of this Client.  # noqa: E501

        The user's display name on the channel.  # noqa: E501

        :return: The display_name of this Client.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Client.

        The user's display name on the channel.  # noqa: E501

        :param display_name: The display_name of this Client.  # noqa: E501
        :type: str
        """
        if type(display_name) is Undefined:
            display_name = None
            self.nulls.discard("display_name")
        elif display_name is None:
            self.nulls.add("display_name")
        else:
            self.nulls.discard("display_name")

        self._display_name = display_name

    @property
    def avatar_url(self):
        """Gets the avatar_url of this Client.  # noqa: E501

        The URL for the user's avatar on the channel.  # noqa: E501

        :return: The avatar_url of this Client.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this Client.

        The URL for the user's avatar on the channel.  # noqa: E501

        :param avatar_url: The avatar_url of this Client.  # noqa: E501
        :type: str
        """
        if type(avatar_url) is Undefined:
            avatar_url = None
            self.nulls.discard("avatar_url")
        elif avatar_url is None:
            self.nulls.add("avatar_url")
        else:
            self.nulls.discard("avatar_url")

        self._avatar_url = avatar_url

    @property
    def info(self):
        """Gets the info of this Client.  # noqa: E501

        A flat curated object with properties that vary for each client platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :return: The info of this Client.  # noqa: E501
        :rtype: object
        """
        return self._info

    @info.setter
    def info(self, info):
        """Sets the info of this Client.

        A flat curated object with properties that vary for each client platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :param info: The info of this Client.  # noqa: E501
        :type: object
        """
        if type(info) is Undefined:
            info = None
            self.nulls.discard("info")
        elif info is None:
            self.nulls.add("info")
        else:
            self.nulls.discard("info")

        self._info = info

    @property
    def raw(self):
        """Gets the raw of this Client.  # noqa: E501

        An object with raw properties that vary for each client platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :return: The raw of this Client.  # noqa: E501
        :rtype: object
        """
        return self._raw

    @raw.setter
    def raw(self, raw):
        """Sets the raw of this Client.

        An object with raw properties that vary for each client platform. All keys are optional and not guaranteed to be available.  # noqa: E501

        :param raw: The raw of this Client.  # noqa: E501
        :type: object
        """
        if type(raw) is Undefined:
            raw = None
            self.nulls.discard("raw")
        elif raw is None:
            self.nulls.add("raw")
        else:
            self.nulls.discard("raw")

        self._raw = raw

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Client):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Client):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined

try:
    Integration = __import__("sunshine_conversations_client.model."+re.sub(r'(?<!^)(?=[A-Z])', '_', "Integration").lower(), fromlist=("Integration")).Integration
except ImportError:
    pass

class Instagram(Integration):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'page_access_token': 'str',
        'app_id': 'str',
        'app_secret': 'str',
        'business_name': 'str',
        'business_username': 'str',
        'page_id': 'str',
        'business_id': 'str',
        'username': 'str',
        'user_id': 'str',
        'default_responder_id': 'str',
        'default_responder': 'DefaultResponderDefaultResponder'
    }

    attribute_map = {
        'type': 'type',
        'page_access_token': 'pageAccessToken',
        'app_id': 'appId',
        'app_secret': 'appSecret',
        'business_name': 'businessName',
        'business_username': 'businessUsername',
        'page_id': 'pageId',
        'business_id': 'businessId',
        'username': 'username',
        'user_id': 'userId',
        'default_responder_id': 'defaultResponderId',
        'default_responder': 'defaultResponder'
    }

    nulls = set()

    def __init__(self, type='instagram', page_access_token=None, app_id=None, app_secret=None, business_name=None, business_username=None, page_id=None, business_id=None, username=None, user_id=None, default_responder_id=Undefined(), default_responder=None, local_vars_configuration=None, **kwargs):  # noqa: E501
        """Instagram - a model defined in OpenAPI"""  # noqa: E501
        super().__init__(**kwargs)

        if (super().openapi_types is not None):
            all_types = super().openapi_types.copy()
            all_types.update(self.openapi_types)
            self.openapi_types = all_types

        if (super().attribute_map is not None):
            all_attributes = super().attribute_map.copy()
            all_attributes.update(self.attribute_map)
            self.attribute_map = all_attributes
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._page_access_token = None
        self._app_id = None
        self._app_secret = None
        self._business_name = None
        self._business_username = None
        self._page_id = None
        self._business_id = None
        self._username = None
        self._user_id = None
        self._default_responder_id = None
        self._default_responder = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if page_access_token is not None:
            self.page_access_token = page_access_token
        self.app_id = app_id
        if app_secret is not None:
            self.app_secret = app_secret
        if business_name is not None:
            self.business_name = business_name
        if business_username is not None:
            self.business_username = business_username
        if page_id is not None:
            self.page_id = page_id
        if business_id is not None:
            self.business_id = business_id
        if username is not None:
            self.username = username
        if user_id is not None:
            self.user_id = user_id
        self.default_responder_id = default_responder_id
        if default_responder is not None:
            self.default_responder = default_responder

    @property
    def type(self):
        """Gets the type of this Instagram.  # noqa: E501

        Instagram Direct setup steps:   - Take note of your Facebook app ID and secret (apps can be created at [developer.facebook.com](https://developer.facebook.com));   - The Facebook app must have been submitted to Meta for app review with the \"pages_manage_metadata\" (to retrieve Page Access Tokens for the Pages and apps that the app user administers and to set a webhook), \"instagram_basic\", and \"instagram_manage_messages\" (to retrieve basic Instagram account information and send messages) permissions.   - In order to integrate an Instagram Direct app, you must acquire a Page Access Token from your user. Once you have acquired a page access token from your user, call the Create Integration endpoint with your app secret and ID and the user’s page access token.   # noqa: E501

        :return: The type of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Instagram.

        Instagram Direct setup steps:   - Take note of your Facebook app ID and secret (apps can be created at [developer.facebook.com](https://developer.facebook.com));   - The Facebook app must have been submitted to Meta for app review with the \"pages_manage_metadata\" (to retrieve Page Access Tokens for the Pages and apps that the app user administers and to set a webhook), \"instagram_basic\", and \"instagram_manage_messages\" (to retrieve basic Instagram account information and send messages) permissions.   - In order to integrate an Instagram Direct app, you must acquire a Page Access Token from your user. Once you have acquired a page access token from your user, call the Create Integration endpoint with your app secret and ID and the user’s page access token.   # noqa: E501

        :param type: The type of this Instagram.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def page_access_token(self):
        """Gets the page_access_token of this Instagram.  # noqa: E501

        The Facebook Page Access Token of the Facebook page that is linked to your Instagram account.  # noqa: E501

        :return: The page_access_token of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._page_access_token

    @page_access_token.setter
    def page_access_token(self, page_access_token):
        """Sets the page_access_token of this Instagram.

        The Facebook Page Access Token of the Facebook page that is linked to your Instagram account.  # noqa: E501

        :param page_access_token: The page_access_token of this Instagram.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and page_access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `page_access_token`, must not be `None`")  # noqa: E501

        self._page_access_token = page_access_token

    @property
    def app_id(self):
        """Gets the app_id of this Instagram.  # noqa: E501

        Your Facebook App ID.  # noqa: E501

        :return: The app_id of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this Instagram.

        Your Facebook App ID.  # noqa: E501

        :param app_id: The app_id of this Instagram.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and app_id is None:  # noqa: E501
            raise ValueError("Invalid value for `app_id`, must not be `None`")  # noqa: E501

        self._app_id = app_id

    @property
    def app_secret(self):
        """Gets the app_secret of this Instagram.  # noqa: E501

        Your Facebook App secret.  # noqa: E501

        :return: The app_secret of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._app_secret

    @app_secret.setter
    def app_secret(self, app_secret):
        """Sets the app_secret of this Instagram.

        Your Facebook App secret.  # noqa: E501

        :param app_secret: The app_secret of this Instagram.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and app_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `app_secret`, must not be `None`")  # noqa: E501

        self._app_secret = app_secret

    @property
    def business_name(self):
        """Gets the business_name of this Instagram.  # noqa: E501

        Your Instagram Business account name  # noqa: E501

        :return: The business_name of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """Sets the business_name of this Instagram.

        Your Instagram Business account name  # noqa: E501

        :param business_name: The business_name of this Instagram.  # noqa: E501
        :type: str
        """

        self._business_name = business_name

    @property
    def business_username(self):
        """Gets the business_username of this Instagram.  # noqa: E501

        Your Instagram Business unique username  # noqa: E501

        :return: The business_username of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._business_username

    @business_username.setter
    def business_username(self, business_username):
        """Sets the business_username of this Instagram.

        Your Instagram Business unique username  # noqa: E501

        :param business_username: The business_username of this Instagram.  # noqa: E501
        :type: str
        """

        self._business_username = business_username

    @property
    def page_id(self):
        """Gets the page_id of this Instagram.  # noqa: E501

        The ID of the Facebook Page linked to your Instagram Business account  # noqa: E501

        :return: The page_id of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this Instagram.

        The ID of the Facebook Page linked to your Instagram Business account  # noqa: E501

        :param page_id: The page_id of this Instagram.  # noqa: E501
        :type: str
        """

        self._page_id = page_id

    @property
    def business_id(self):
        """Gets the business_id of this Instagram.  # noqa: E501

        The ID of the Instagram Business account  # noqa: E501

        :return: The business_id of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._business_id

    @business_id.setter
    def business_id(self, business_id):
        """Sets the business_id of this Instagram.

        The ID of the Instagram Business account  # noqa: E501

        :param business_id: The business_id of this Instagram.  # noqa: E501
        :type: str
        """

        self._business_id = business_id

    @property
    def username(self):
        """Gets the username of this Instagram.  # noqa: E501

        The Facebook user's username. This is returned when integrating through the Dashboard  # noqa: E501

        :return: The username of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this Instagram.

        The Facebook user's username. This is returned when integrating through the Dashboard  # noqa: E501

        :param username: The username of this Instagram.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def user_id(self):
        """Gets the user_id of this Instagram.  # noqa: E501

        The Facebook user's user ID. This is returned when integrating through the Dashboard  # noqa: E501

        :return: The user_id of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Instagram.

        The Facebook user's user ID. This is returned when integrating through the Dashboard  # noqa: E501

        :param user_id: The user_id of this Instagram.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this Instagram.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this Instagram.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this Instagram.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this Instagram.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def default_responder(self):
        """Gets the default_responder of this Instagram.  # noqa: E501


        :return: The default_responder of this Instagram.  # noqa: E501
        :rtype: DefaultResponderDefaultResponder
        """
        return self._default_responder

    @default_responder.setter
    def default_responder(self, default_responder):
        """Sets the default_responder of this Instagram.


        :param default_responder: The default_responder of this Instagram.  # noqa: E501
        :type: DefaultResponderDefaultResponder
        """

        self._default_responder = default_responder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Instagram):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Instagram):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class IosUpdate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'default_responder_id': 'str',
        'certificate': 'str',
        'password': 'str',
        'production': 'bool',
        'auto_update_badge': 'bool',
        'can_user_create_more_conversations': 'bool'
    }

    attribute_map = {
        'display_name': 'displayName',
        'default_responder_id': 'defaultResponderId',
        'certificate': 'certificate',
        'password': 'password',
        'production': 'production',
        'auto_update_badge': 'autoUpdateBadge',
        'can_user_create_more_conversations': 'canUserCreateMoreConversations'
    }

    nulls = set()

    def __init__(self, display_name=Undefined(), default_responder_id=Undefined(), certificate=Undefined(), password=None, production=None, auto_update_badge=None, can_user_create_more_conversations=None, local_vars_configuration=None):  # noqa: E501
        """IosUpdate - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._default_responder_id = None
        self._certificate = None
        self._password = None
        self._production = None
        self._auto_update_badge = None
        self._can_user_create_more_conversations = None
        self.discriminator = None

        self.display_name = display_name
        self.default_responder_id = default_responder_id
        self.certificate = certificate
        if password is not None:
            self.password = password
        if production is not None:
            self.production = production
        if auto_update_badge is not None:
            self.auto_update_badge = auto_update_badge
        if can_user_create_more_conversations is not None:
            self.can_user_create_more_conversations = can_user_create_more_conversations

    @property
    def display_name(self):
        """Gets the display_name of this IosUpdate.  # noqa: E501

        A human-friendly name used to identify the integration. `displayName` can be unset by changing it to `null`.  # noqa: E501

        :return: The display_name of this IosUpdate.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this IosUpdate.

        A human-friendly name used to identify the integration. `displayName` can be unset by changing it to `null`.  # noqa: E501

        :param display_name: The display_name of this IosUpdate.  # noqa: E501
        :type: str
        """
        if type(display_name) is Undefined:
            display_name = None
            self.nulls.discard("display_name")
        elif display_name is None:
            self.nulls.add("display_name")
        else:
            self.nulls.discard("display_name")
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 100):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) < 1):
            raise ValueError("Invalid value for `display_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._display_name = display_name

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this IosUpdate.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this IosUpdate.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this IosUpdate.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this IosUpdate.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def certificate(self):
        """Gets the certificate of this IosUpdate.  # noqa: E501

        The binary of your APN certificate base64 encoded.  # noqa: E501

        :return: The certificate of this IosUpdate.  # noqa: E501
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """Sets the certificate of this IosUpdate.

        The binary of your APN certificate base64 encoded.  # noqa: E501

        :param certificate: The certificate of this IosUpdate.  # noqa: E501
        :type: str
        """
        if type(certificate) is Undefined:
            certificate = None
            self.nulls.discard("certificate")
        elif certificate is None:
            self.nulls.add("certificate")
        else:
            self.nulls.discard("certificate")
        if (self.local_vars_configuration.client_side_validation and
                certificate is not None and len(certificate) < 1):
            raise ValueError("Invalid value for `certificate`, length must be greater than or equal to `1`")  # noqa: E501

        self._certificate = certificate

    @property
    def password(self):
        """Gets the password of this IosUpdate.  # noqa: E501

        The password for your APN certificate.  # noqa: E501

        :return: The password of this IosUpdate.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this IosUpdate.

        The password for your APN certificate.  # noqa: E501

        :param password: The password of this IosUpdate.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def production(self):
        """Gets the production of this IosUpdate.  # noqa: E501

        The APN environment to connect to (Production, if true, or Sandbox). Defaults to value inferred from certificate if not specified.  # noqa: E501

        :return: The production of this IosUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """Sets the production of this IosUpdate.

        The APN environment to connect to (Production, if true, or Sandbox). Defaults to value inferred from certificate if not specified.  # noqa: E501

        :param production: The production of this IosUpdate.  # noqa: E501
        :type: bool
        """

        self._production = production

    @property
    def auto_update_badge(self):
        """Gets the auto_update_badge of this IosUpdate.  # noqa: E501

        Use the unread count of the conversation as the application badge.  # noqa: E501

        :return: The auto_update_badge of this IosUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._auto_update_badge

    @auto_update_badge.setter
    def auto_update_badge(self, auto_update_badge):
        """Sets the auto_update_badge of this IosUpdate.

        Use the unread count of the conversation as the application badge.  # noqa: E501

        :param auto_update_badge: The auto_update_badge of this IosUpdate.  # noqa: E501
        :type: bool
        """

        self._auto_update_badge = auto_update_badge

    @property
    def can_user_create_more_conversations(self):
        """Gets the can_user_create_more_conversations of this IosUpdate.  # noqa: E501

        Allows users to create more than one conversation on the iOS integration.  # noqa: E501

        :return: The can_user_create_more_conversations of this IosUpdate.  # noqa: E501
        :rtype: bool
        """
        return self._can_user_create_more_conversations

    @can_user_create_more_conversations.setter
    def can_user_create_more_conversations(self, can_user_create_more_conversations):
        """Sets the can_user_create_more_conversations of this IosUpdate.

        Allows users to create more than one conversation on the iOS integration.  # noqa: E501

        :param can_user_create_more_conversations: The can_user_create_more_conversations of this IosUpdate.  # noqa: E501
        :type: bool
        """

        self._can_user_create_more_conversations = can_user_create_more_conversations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IosUpdate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IosUpdate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class ConversationCreateEventAllOfPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conversation': 'ConversationTruncated',
        'creation_reason': 'str',
        'source': 'SourceWithCampaignWebhook',
        'user': 'User',
        'referral': 'Referral'
    }

    attribute_map = {
        'conversation': 'conversation',
        'creation_reason': 'creationReason',
        'source': 'source',
        'user': 'user',
        'referral': 'referral'
    }

    nulls = set()

    def __init__(self, conversation=None, creation_reason=None, source=None, user=Undefined(), referral=Undefined(), local_vars_configuration=None):  # noqa: E501
        """ConversationCreateEventAllOfPayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conversation = None
        self._creation_reason = None
        self._source = None
        self._user = None
        self._referral = None
        self.discriminator = None

        if conversation is not None:
            self.conversation = conversation
        if creation_reason is not None:
            self.creation_reason = creation_reason
        if source is not None:
            self.source = source
        self.user = user
        self.referral = referral

    @property
    def conversation(self):
        """Gets the conversation of this ConversationCreateEventAllOfPayload.  # noqa: E501

        The conversation that was created.  # noqa: E501

        :return: The conversation of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :rtype: ConversationTruncated
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """Sets the conversation of this ConversationCreateEventAllOfPayload.

        The conversation that was created.  # noqa: E501

        :param conversation: The conversation of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :type: ConversationTruncated
        """

        self._conversation = conversation

    @property
    def creation_reason(self):
        """Gets the creation_reason of this ConversationCreateEventAllOfPayload.  # noqa: E501

        The reason why the conversation was created, if applicable. * `linkRequest` - The conversation was created in order to generate a link request to transfer the user to a different channel. * `message` - The conversation was created because a message was sent. * `none` - The conversation was not created for a specific purpose. Used primarily when a conversation is created via the Create Conversation API. * `notification` - The conversation was created by a call to the Notification API. * `prechatCapture` - The conversation was created because the user completed a prechat capture form in the Web Messenger. * `startConversation` - The conversation was created because of a call to the startConversation API on one of the SDK integrations, or a start conversation event was triggered from a messaging channel. * `proactiveMessaging` - The conversation was created because the user interacted with a campaign.   # noqa: E501

        :return: The creation_reason of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :rtype: str
        """
        return self._creation_reason

    @creation_reason.setter
    def creation_reason(self, creation_reason):
        """Sets the creation_reason of this ConversationCreateEventAllOfPayload.

        The reason why the conversation was created, if applicable. * `linkRequest` - The conversation was created in order to generate a link request to transfer the user to a different channel. * `message` - The conversation was created because a message was sent. * `none` - The conversation was not created for a specific purpose. Used primarily when a conversation is created via the Create Conversation API. * `notification` - The conversation was created by a call to the Notification API. * `prechatCapture` - The conversation was created because the user completed a prechat capture form in the Web Messenger. * `startConversation` - The conversation was created because of a call to the startConversation API on one of the SDK integrations, or a start conversation event was triggered from a messaging channel. * `proactiveMessaging` - The conversation was created because the user interacted with a campaign.   # noqa: E501

        :param creation_reason: The creation_reason of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :type: str
        """
        allowed_values = ["linkRequest", "message", "none", "notification", "prechatCapture", "startConversation", "proactiveMessaging"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and creation_reason not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `creation_reason` ({0}), must be one of {1}"  # noqa: E501
                .format(creation_reason, allowed_values)
            )

        self._creation_reason = creation_reason

    @property
    def source(self):
        """Gets the source of this ConversationCreateEventAllOfPayload.  # noqa: E501

        The source of the creation.  # noqa: E501

        :return: The source of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :rtype: SourceWithCampaignWebhook
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ConversationCreateEventAllOfPayload.

        The source of the creation.  # noqa: E501

        :param source: The source of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :type: SourceWithCampaignWebhook
        """

        self._source = source

    @property
    def user(self):
        """Gets the user of this ConversationCreateEventAllOfPayload.  # noqa: E501

        The user associated with the conversation. Only present if the created conversation was of type personal. For sdkGroup conversations, the list of participants can be fetched using the List Participants API, if required.  # noqa: E501

        :return: The user of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ConversationCreateEventAllOfPayload.

        The user associated with the conversation. Only present if the created conversation was of type personal. For sdkGroup conversations, the list of participants can be fetched using the List Participants API, if required.  # noqa: E501

        :param user: The user of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :type: User
        """
        if type(user) is Undefined:
            user = None
            self.nulls.discard("user")
        elif user is None:
            self.nulls.add("user")
        else:
            self.nulls.discard("user")

        self._user = user

    @property
    def referral(self):
        """Gets the referral of this ConversationCreateEventAllOfPayload.  # noqa: E501

        Referral information, if applicable.  # noqa: E501

        :return: The referral of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :rtype: Referral
        """
        return self._referral

    @referral.setter
    def referral(self, referral):
        """Sets the referral of this ConversationCreateEventAllOfPayload.

        Referral information, if applicable.  # noqa: E501

        :param referral: The referral of this ConversationCreateEventAllOfPayload.  # noqa: E501
        :type: Referral
        """
        if type(referral) is Undefined:
            referral = None
            self.nulls.discard("referral")
        elif referral is None:
            self.nulls.add("referral")
        else:
            self.nulls.discard("referral")

        self._referral = referral

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversationCreateEventAllOfPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversationCreateEventAllOfPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class DefaultResponderId(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_responder_id': 'str'
    }

    attribute_map = {
        'default_responder_id': 'defaultResponderId'
    }

    nulls = set()

    def __init__(self, default_responder_id=Undefined(), local_vars_configuration=None):  # noqa: E501
        """DefaultResponderId - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default_responder_id = None
        self.discriminator = None

        self.default_responder_id = default_responder_id

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this DefaultResponderId.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this DefaultResponderId.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this DefaultResponderId.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this DefaultResponderId.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultResponderId):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DefaultResponderId):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class SwitchboardIntegration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'integration_id': 'str',
        'integration_type': 'str',
        'deliver_standby_events': 'bool',
        'next_switchboard_integration_id': 'str',
        'message_history_count': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'integration_id': 'integrationId',
        'integration_type': 'integrationType',
        'deliver_standby_events': 'deliverStandbyEvents',
        'next_switchboard_integration_id': 'nextSwitchboardIntegrationId',
        'message_history_count': 'messageHistoryCount'
    }

    nulls = set()

    def __init__(self, id=None, name=None, integration_id=None, integration_type=None, deliver_standby_events=None, next_switchboard_integration_id=None, message_history_count=Undefined(), local_vars_configuration=None):  # noqa: E501
        """SwitchboardIntegration - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._integration_id = None
        self._integration_type = None
        self._deliver_standby_events = None
        self._next_switchboard_integration_id = None
        self._message_history_count = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.integration_id = integration_id
        self.integration_type = integration_type
        self.deliver_standby_events = deliver_standby_events
        if next_switchboard_integration_id is not None:
            self.next_switchboard_integration_id = next_switchboard_integration_id
        self.message_history_count = message_history_count

    @property
    def id(self):
        """Gets the id of this SwitchboardIntegration.  # noqa: E501

        The unique ID of the switchboard integration.  # noqa: E501

        :return: The id of this SwitchboardIntegration.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SwitchboardIntegration.

        The unique ID of the switchboard integration.  # noqa: E501

        :param id: The id of this SwitchboardIntegration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this SwitchboardIntegration.  # noqa: E501

        Identifier for use in control transfer protocols. Restricted to alphanumeric characters, `-` and `_`.  # noqa: E501

        :return: The name of this SwitchboardIntegration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SwitchboardIntegration.

        Identifier for use in control transfer protocols. Restricted to alphanumeric characters, `-` and `_`.  # noqa: E501

        :param name: The name of this SwitchboardIntegration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 128):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `128`")  # noqa: E501

        self._name = name

    @property
    def integration_id(self):
        """Gets the integration_id of this SwitchboardIntegration.  # noqa: E501

        Id of the integration that should deliver events routed by the switchboard.  # noqa: E501

        :return: The integration_id of this SwitchboardIntegration.  # noqa: E501
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this SwitchboardIntegration.

        Id of the integration that should deliver events routed by the switchboard.  # noqa: E501

        :param integration_id: The integration_id of this SwitchboardIntegration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and integration_id is None:  # noqa: E501
            raise ValueError("Invalid value for `integration_id`, must not be `None`")  # noqa: E501

        self._integration_id = integration_id

    @property
    def integration_type(self):
        """Gets the integration_type of this SwitchboardIntegration.  # noqa: E501

        Type of integration that should deliver events routed by the switchboard. If referencing an OAuth integration, the clientId issued by Sunshine Conversations during the OAuth partnership process will be the value of integrationType.  # noqa: E501

        :return: The integration_type of this SwitchboardIntegration.  # noqa: E501
        :rtype: str
        """
        return self._integration_type

    @integration_type.setter
    def integration_type(self, integration_type):
        """Sets the integration_type of this SwitchboardIntegration.

        Type of integration that should deliver events routed by the switchboard. If referencing an OAuth integration, the clientId issued by Sunshine Conversations during the OAuth partnership process will be the value of integrationType.  # noqa: E501

        :param integration_type: The integration_type of this SwitchboardIntegration.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and integration_type is None:  # noqa: E501
            raise ValueError("Invalid value for `integration_type`, must not be `None`")  # noqa: E501

        self._integration_type = integration_type

    @property
    def deliver_standby_events(self):
        """Gets the deliver_standby_events of this SwitchboardIntegration.  # noqa: E501

        Setting to determine if webhooks should be sent when the switchboard integration is not in control of a conversation (standby status)  # noqa: E501

        :return: The deliver_standby_events of this SwitchboardIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._deliver_standby_events

    @deliver_standby_events.setter
    def deliver_standby_events(self, deliver_standby_events):
        """Sets the deliver_standby_events of this SwitchboardIntegration.

        Setting to determine if webhooks should be sent when the switchboard integration is not in control of a conversation (standby status)  # noqa: E501

        :param deliver_standby_events: The deliver_standby_events of this SwitchboardIntegration.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and deliver_standby_events is None:  # noqa: E501
            raise ValueError("Invalid value for `deliver_standby_events`, must not be `None`")  # noqa: E501

        self._deliver_standby_events = deliver_standby_events

    @property
    def next_switchboard_integration_id(self):
        """Gets the next_switchboard_integration_id of this SwitchboardIntegration.  # noqa: E501

        The switchboard integration id to which control of a conversation is passed / offered by default.  # noqa: E501

        :return: The next_switchboard_integration_id of this SwitchboardIntegration.  # noqa: E501
        :rtype: str
        """
        return self._next_switchboard_integration_id

    @next_switchboard_integration_id.setter
    def next_switchboard_integration_id(self, next_switchboard_integration_id):
        """Sets the next_switchboard_integration_id of this SwitchboardIntegration.

        The switchboard integration id to which control of a conversation is passed / offered by default.  # noqa: E501

        :param next_switchboard_integration_id: The next_switchboard_integration_id of this SwitchboardIntegration.  # noqa: E501
        :type: str
        """

        self._next_switchboard_integration_id = next_switchboard_integration_id

    @property
    def message_history_count(self):
        """Gets the message_history_count of this SwitchboardIntegration.  # noqa: E501

        Number of messages to include in the message history context.  # noqa: E501

        :return: The message_history_count of this SwitchboardIntegration.  # noqa: E501
        :rtype: int
        """
        return self._message_history_count

    @message_history_count.setter
    def message_history_count(self, message_history_count):
        """Sets the message_history_count of this SwitchboardIntegration.

        Number of messages to include in the message history context.  # noqa: E501

        :param message_history_count: The message_history_count of this SwitchboardIntegration.  # noqa: E501
        :type: int
        """
        if type(message_history_count) is Undefined:
            message_history_count = None
            self.nulls.discard("message_history_count")
        elif message_history_count is None:
            self.nulls.add("message_history_count")
        else:
            self.nulls.discard("message_history_count")
        if (self.local_vars_configuration.client_side_validation and
                message_history_count is not None and message_history_count > 10):  # noqa: E501
            raise ValueError("Invalid value for `message_history_count`, must be a value less than or equal to `10`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                message_history_count is not None and message_history_count < 1):  # noqa: E501
            raise ValueError("Invalid value for `message_history_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._message_history_count = message_history_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwitchboardIntegration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SwitchboardIntegration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined

try:
    Integration = __import__("sunshine_conversations_client.model."+re.sub(r'(?<!^)(?=[A-Z])', '_', "Integration").lower(), fromlist=("Integration")).Integration
except ImportError:
    pass

class Messenger(Integration):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'page_access_token': 'str',
        'app_id': 'str',
        'app_secret': 'str',
        'page_id': 'float',
        'page_name': 'str',
        'default_responder_id': 'str',
        'default_responder': 'DefaultResponderDefaultResponder'
    }

    attribute_map = {
        'type': 'type',
        'page_access_token': 'pageAccessToken',
        'app_id': 'appId',
        'app_secret': 'appSecret',
        'page_id': 'pageId',
        'page_name': 'pageName',
        'default_responder_id': 'defaultResponderId',
        'default_responder': 'defaultResponder'
    }

    nulls = set()

    def __init__(self, type='messenger', page_access_token=None, app_id=None, app_secret=None, page_id=None, page_name=None, default_responder_id=Undefined(), default_responder=None, local_vars_configuration=None, **kwargs):  # noqa: E501
        """Messenger - a model defined in OpenAPI"""  # noqa: E501
        super().__init__(**kwargs)

        if (super().openapi_types is not None):
            all_types = super().openapi_types.copy()
            all_types.update(self.openapi_types)
            self.openapi_types = all_types

        if (super().attribute_map is not None):
            all_attributes = super().attribute_map.copy()
            all_attributes.update(self.attribute_map)
            self.attribute_map = all_attributes
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._page_access_token = None
        self._app_id = None
        self._app_secret = None
        self._page_id = None
        self._page_name = None
        self._default_responder_id = None
        self._default_responder = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.page_access_token = page_access_token
        self.app_id = app_id
        if app_secret is not None:
            self.app_secret = app_secret
        if page_id is not None:
            self.page_id = page_id
        if page_name is not None:
            self.page_name = page_name
        self.default_responder_id = default_responder_id
        if default_responder is not None:
            self.default_responder = default_responder

    @property
    def type(self):
        """Gets the type of this Messenger.  # noqa: E501

        Facebook Messenger Setup steps: - Take note of your Facebook app ID and secret (apps can be created at developer.facebook.com); - The Facebook app must have been submitted to Meta for app review with the “pages_manage_metadata” (to retrieve Page Access Tokens for the Pages, apps that the app user administers and set a webhook) and “pages_messaging” (to send messages) permissions. - In order to integrate a Facebook Messenger app you must acquire a Page Access Token from your user. Once you have acquired a page access token from your user, call the Create Integration endpoint with your app secret and ID and the user’s page access token.   # noqa: E501

        :return: The type of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Messenger.

        Facebook Messenger Setup steps: - Take note of your Facebook app ID and secret (apps can be created at developer.facebook.com); - The Facebook app must have been submitted to Meta for app review with the “pages_manage_metadata” (to retrieve Page Access Tokens for the Pages, apps that the app user administers and set a webhook) and “pages_messaging” (to send messages) permissions. - In order to integrate a Facebook Messenger app you must acquire a Page Access Token from your user. Once you have acquired a page access token from your user, call the Create Integration endpoint with your app secret and ID and the user’s page access token.   # noqa: E501

        :param type: The type of this Messenger.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def page_access_token(self):
        """Gets the page_access_token of this Messenger.  # noqa: E501

        A Facebook Page Access Token.  # noqa: E501

        :return: The page_access_token of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._page_access_token

    @page_access_token.setter
    def page_access_token(self, page_access_token):
        """Sets the page_access_token of this Messenger.

        A Facebook Page Access Token.  # noqa: E501

        :param page_access_token: The page_access_token of this Messenger.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and page_access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `page_access_token`, must not be `None`")  # noqa: E501

        self._page_access_token = page_access_token

    @property
    def app_id(self):
        """Gets the app_id of this Messenger.  # noqa: E501

        A Facebook App ID.  # noqa: E501

        :return: The app_id of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this Messenger.

        A Facebook App ID.  # noqa: E501

        :param app_id: The app_id of this Messenger.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and app_id is None:  # noqa: E501
            raise ValueError("Invalid value for `app_id`, must not be `None`")  # noqa: E501

        self._app_id = app_id

    @property
    def app_secret(self):
        """Gets the app_secret of this Messenger.  # noqa: E501

        A Facebook App Secret.  # noqa: E501

        :return: The app_secret of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._app_secret

    @app_secret.setter
    def app_secret(self, app_secret):
        """Sets the app_secret of this Messenger.

        A Facebook App Secret.  # noqa: E501

        :param app_secret: The app_secret of this Messenger.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and app_secret is None:  # noqa: E501
            raise ValueError("Invalid value for `app_secret`, must not be `None`")  # noqa: E501

        self._app_secret = app_secret

    @property
    def page_id(self):
        """Gets the page_id of this Messenger.  # noqa: E501

        A Facebook page ID.  # noqa: E501

        :return: The page_id of this Messenger.  # noqa: E501
        :rtype: float
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this Messenger.

        A Facebook page ID.  # noqa: E501

        :param page_id: The page_id of this Messenger.  # noqa: E501
        :type: float
        """

        self._page_id = page_id

    @property
    def page_name(self):
        """Gets the page_name of this Messenger.  # noqa: E501

        A Facebook page name.  # noqa: E501

        :return: The page_name of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._page_name

    @page_name.setter
    def page_name(self, page_name):
        """Sets the page_name of this Messenger.

        A Facebook page name.  # noqa: E501

        :param page_name: The page_name of this Messenger.  # noqa: E501
        :type: str
        """

        self._page_name = page_name

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this Messenger.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this Messenger.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this Messenger.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this Messenger.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def default_responder(self):
        """Gets the default_responder of this Messenger.  # noqa: E501


        :return: The default_responder of this Messenger.  # noqa: E501
        :rtype: DefaultResponderDefaultResponder
        """
        return self._default_responder

    @default_responder.setter
    def default_responder(self, default_responder):
        """Sets the default_responder of this Messenger.


        :param default_responder: The default_responder of this Messenger.  # noqa: E501
        :type: DefaultResponderDefaultResponder
        """

        self._default_responder = default_responder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Messenger):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Messenger):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class UserUpdateEventAllOfPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'User',
        'reason': 'str',
        'source': 'SourceWebhook'
    }

    attribute_map = {
        'user': 'user',
        'reason': 'reason',
        'source': 'source'
    }

    nulls = set()

    def __init__(self, user=None, reason=None, source=None, local_vars_configuration=None):  # noqa: E501
        """UserUpdateEventAllOfPayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._reason = None
        self._source = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if reason is not None:
            self.reason = reason
        if source is not None:
            self.source = source

    @property
    def user(self):
        """Gets the user of this UserUpdateEventAllOfPayload.  # noqa: E501

        The updated user.  # noqa: E501

        :return: The user of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this UserUpdateEventAllOfPayload.

        The updated user.  # noqa: E501

        :param user: The user of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: User
        """

        self._user = user

    @property
    def reason(self):
        """Gets the reason of this UserUpdateEventAllOfPayload.  # noqa: E501

        The reason why the user was updated, if applicable. * `authentication` - An anonymous user became an [identified](https://docs.smooch.io/guide/intro-to-users/) user. * `localeDetection` - A user was updated as a result of automated locale detection on messages sent.   # noqa: E501

        :return: The reason of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this UserUpdateEventAllOfPayload.

        The reason why the user was updated, if applicable. * `authentication` - An anonymous user became an [identified](https://docs.smooch.io/guide/intro-to-users/) user. * `localeDetection` - A user was updated as a result of automated locale detection on messages sent.   # noqa: E501

        :param reason: The reason of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: str
        """
        allowed_values = ["authentication", "localeDetection"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reason not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `reason` ({0}), must be one of {1}"  # noqa: E501
                .format(reason, allowed_values)
            )

        self._reason = reason

    @property
    def source(self):
        """Gets the source of this UserUpdateEventAllOfPayload.  # noqa: E501

        The source of the creation.  # noqa: E501

        :return: The source of this UserUpdateEventAllOfPayload.  # noqa: E501
        :rtype: SourceWebhook
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this UserUpdateEventAllOfPayload.

        The source of the creation.  # noqa: E501

        :param source: The source of this UserUpdateEventAllOfPayload.  # noqa: E501
        :type: SourceWebhook
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserUpdateEventAllOfPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserUpdateEventAllOfPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class AppSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conversation_retention_seconds': 'int',
        'mask_credit_card_numbers': 'bool',
        'use_animal_names': 'bool',
        'echo_postback': 'bool',
        'ignore_auto_conversation_start': 'bool',
        'multi_convo_enabled': 'bool',
        'app_localization_enabled': 'bool'
    }

    attribute_map = {
        'conversation_retention_seconds': 'conversationRetentionSeconds',
        'mask_credit_card_numbers': 'maskCreditCardNumbers',
        'use_animal_names': 'useAnimalNames',
        'echo_postback': 'echoPostback',
        'ignore_auto_conversation_start': 'ignoreAutoConversationStart',
        'multi_convo_enabled': 'multiConvoEnabled',
        'app_localization_enabled': 'appLocalizationEnabled'
    }

    nulls = set()

    def __init__(self, conversation_retention_seconds=None, mask_credit_card_numbers=None, use_animal_names=None, echo_postback=None, ignore_auto_conversation_start=None, multi_convo_enabled=None, app_localization_enabled=None, local_vars_configuration=None):  # noqa: E501
        """AppSettings - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conversation_retention_seconds = None
        self._mask_credit_card_numbers = None
        self._use_animal_names = None
        self._echo_postback = None
        self._ignore_auto_conversation_start = None
        self._multi_convo_enabled = None
        self._app_localization_enabled = None
        self.discriminator = None

        if conversation_retention_seconds is not None:
            self.conversation_retention_seconds = conversation_retention_seconds
        if mask_credit_card_numbers is not None:
            self.mask_credit_card_numbers = mask_credit_card_numbers
        if use_animal_names is not None:
            self.use_animal_names = use_animal_names
        if echo_postback is not None:
            self.echo_postback = echo_postback
        if ignore_auto_conversation_start is not None:
            self.ignore_auto_conversation_start = ignore_auto_conversation_start
        if multi_convo_enabled is not None:
            self.multi_convo_enabled = multi_convo_enabled
        if app_localization_enabled is not None:
            self.app_localization_enabled = app_localization_enabled

    @property
    def conversation_retention_seconds(self):
        """Gets the conversation_retention_seconds of this AppSettings.  # noqa: E501

        Number of seconds of inactivity before a conversation’s messages  will be automatically deleted. See  [Conversation Retention Seconds](https://docs.smooch.io/guide/creating-and-managing-apps/#conversation-retention-seconds) for more information.   # noqa: E501

        :return: The conversation_retention_seconds of this AppSettings.  # noqa: E501
        :rtype: int
        """
        return self._conversation_retention_seconds

    @conversation_retention_seconds.setter
    def conversation_retention_seconds(self, conversation_retention_seconds):
        """Sets the conversation_retention_seconds of this AppSettings.

        Number of seconds of inactivity before a conversation’s messages  will be automatically deleted. See  [Conversation Retention Seconds](https://docs.smooch.io/guide/creating-and-managing-apps/#conversation-retention-seconds) for more information.   # noqa: E501

        :param conversation_retention_seconds: The conversation_retention_seconds of this AppSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                conversation_retention_seconds is not None and conversation_retention_seconds < 0):  # noqa: E501
            raise ValueError("Invalid value for `conversation_retention_seconds`, must be a value greater than or equal to `0`")  # noqa: E501

        self._conversation_retention_seconds = conversation_retention_seconds

    @property
    def mask_credit_card_numbers(self):
        """Gets the mask_credit_card_numbers of this AppSettings.  # noqa: E501

        A boolean specifying whether credit card numbers should be masked  when sent through Sunshine Conversations.   # noqa: E501

        :return: The mask_credit_card_numbers of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._mask_credit_card_numbers

    @mask_credit_card_numbers.setter
    def mask_credit_card_numbers(self, mask_credit_card_numbers):
        """Sets the mask_credit_card_numbers of this AppSettings.

        A boolean specifying whether credit card numbers should be masked  when sent through Sunshine Conversations.   # noqa: E501

        :param mask_credit_card_numbers: The mask_credit_card_numbers of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._mask_credit_card_numbers = mask_credit_card_numbers

    @property
    def use_animal_names(self):
        """Gets the use_animal_names of this AppSettings.  # noqa: E501

        A boolean specifying whether animal names should be used for  unnamed users. See the  [user naming guide](https://docs.smooch.io/guide/receiving-messages/#message-author-name) for details.   # noqa: E501

        :return: The use_animal_names of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._use_animal_names

    @use_animal_names.setter
    def use_animal_names(self, use_animal_names):
        """Sets the use_animal_names of this AppSettings.

        A boolean specifying whether animal names should be used for  unnamed users. See the  [user naming guide](https://docs.smooch.io/guide/receiving-messages/#message-author-name) for details.   # noqa: E501

        :param use_animal_names: The use_animal_names of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._use_animal_names = use_animal_names

    @property
    def echo_postback(self):
        """Gets the echo_postback of this AppSettings.  # noqa: E501

        A boolean specifying whether a message should be added to the conversation  history when a postback button is clicked. See  [Echo Postbacks](https://docs.smooch.io/guide/creating-and-managing-apps/#echo-postbacks) for more information.   # noqa: E501

        :return: The echo_postback of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._echo_postback

    @echo_postback.setter
    def echo_postback(self, echo_postback):
        """Sets the echo_postback of this AppSettings.

        A boolean specifying whether a message should be added to the conversation  history when a postback button is clicked. See  [Echo Postbacks](https://docs.smooch.io/guide/creating-and-managing-apps/#echo-postbacks) for more information.   # noqa: E501

        :param echo_postback: The echo_postback of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._echo_postback = echo_postback

    @property
    def ignore_auto_conversation_start(self):
        """Gets the ignore_auto_conversation_start of this AppSettings.  # noqa: E501

        A boolean specifying whether a non message event coming from a channel will  trigger a  [start conversation](https://docs.smooch.io/rest/#section/Webhook-Triggers) event and count as a monthly active user (MAU). <aside class=\"notice\">Calling <code>startConversation()</code> (or equivalent) from the Android,  iOS or Web SDK will count as a MAU, regardless of the value of this setting.</aside>   # noqa: E501

        :return: The ignore_auto_conversation_start of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_auto_conversation_start

    @ignore_auto_conversation_start.setter
    def ignore_auto_conversation_start(self, ignore_auto_conversation_start):
        """Sets the ignore_auto_conversation_start of this AppSettings.

        A boolean specifying whether a non message event coming from a channel will  trigger a  [start conversation](https://docs.smooch.io/rest/#section/Webhook-Triggers) event and count as a monthly active user (MAU). <aside class=\"notice\">Calling <code>startConversation()</code> (or equivalent) from the Android,  iOS or Web SDK will count as a MAU, regardless of the value of this setting.</aside>   # noqa: E501

        :param ignore_auto_conversation_start: The ignore_auto_conversation_start of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._ignore_auto_conversation_start = ignore_auto_conversation_start

    @property
    def multi_convo_enabled(self):
        """Gets the multi_convo_enabled of this AppSettings.  # noqa: E501

        A boolean specifying whether users are allowed to be part of several conversations. Enabling `multiConvo` is **irreversible**.   # noqa: E501

        :return: The multi_convo_enabled of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._multi_convo_enabled

    @multi_convo_enabled.setter
    def multi_convo_enabled(self, multi_convo_enabled):
        """Sets the multi_convo_enabled of this AppSettings.

        A boolean specifying whether users are allowed to be part of several conversations. Enabling `multiConvo` is **irreversible**.   # noqa: E501

        :param multi_convo_enabled: The multi_convo_enabled of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._multi_convo_enabled = multi_convo_enabled

    @property
    def app_localization_enabled(self):
        """Gets the app_localization_enabled of this AppSettings.  # noqa: E501

        A boolean specifying whether the messages authored by the Sunshine Conversations platform should be localized.   # noqa: E501

        :return: The app_localization_enabled of this AppSettings.  # noqa: E501
        :rtype: bool
        """
        return self._app_localization_enabled

    @app_localization_enabled.setter
    def app_localization_enabled(self, app_localization_enabled):
        """Sets the app_localization_enabled of this AppSettings.

        A boolean specifying whether the messages authored by the Sunshine Conversations platform should be localized.   # noqa: E501

        :param app_localization_enabled: The app_localization_enabled of this AppSettings.  # noqa: E501
        :type: bool
        """

        self._app_localization_enabled = app_localization_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class Profile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'given_name': 'str',
        'surname': 'str',
        'email': 'str',
        'avatar_url': 'str',
        'locale': 'str'
    }

    attribute_map = {
        'given_name': 'givenName',
        'surname': 'surname',
        'email': 'email',
        'avatar_url': 'avatarUrl',
        'locale': 'locale'
    }

    nulls = set()

    def __init__(self, given_name=Undefined(), surname=Undefined(), email=Undefined(), avatar_url=Undefined(), locale=Undefined(), local_vars_configuration=None):  # noqa: E501
        """Profile - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._given_name = None
        self._surname = None
        self._email = None
        self._avatar_url = None
        self._locale = None
        self.discriminator = None

        self.given_name = given_name
        self.surname = surname
        self.email = email
        self.avatar_url = avatar_url
        self.locale = locale

    @property
    def given_name(self):
        """Gets the given_name of this Profile.  # noqa: E501

        The user's given name (first name).  # noqa: E501

        :return: The given_name of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._given_name

    @given_name.setter
    def given_name(self, given_name):
        """Sets the given_name of this Profile.

        The user's given name (first name).  # noqa: E501

        :param given_name: The given_name of this Profile.  # noqa: E501
        :type: str
        """
        if type(given_name) is Undefined:
            given_name = None
            self.nulls.discard("given_name")
        elif given_name is None:
            self.nulls.add("given_name")
        else:
            self.nulls.discard("given_name")
        if (self.local_vars_configuration.client_side_validation and
                given_name is not None and len(given_name) > 128):
            raise ValueError("Invalid value for `given_name`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                given_name is not None and len(given_name) < 1):
            raise ValueError("Invalid value for `given_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._given_name = given_name

    @property
    def surname(self):
        """Gets the surname of this Profile.  # noqa: E501

        The user's surname (last name).  # noqa: E501

        :return: The surname of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._surname

    @surname.setter
    def surname(self, surname):
        """Sets the surname of this Profile.

        The user's surname (last name).  # noqa: E501

        :param surname: The surname of this Profile.  # noqa: E501
        :type: str
        """
        if type(surname) is Undefined:
            surname = None
            self.nulls.discard("surname")
        elif surname is None:
            self.nulls.add("surname")
        else:
            self.nulls.discard("surname")
        if (self.local_vars_configuration.client_side_validation and
                surname is not None and len(surname) > 128):
            raise ValueError("Invalid value for `surname`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                surname is not None and len(surname) < 1):
            raise ValueError("Invalid value for `surname`, length must be greater than or equal to `1`")  # noqa: E501

        self._surname = surname

    @property
    def email(self):
        """Gets the email of this Profile.  # noqa: E501

        The user's email address.  # noqa: E501

        :return: The email of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Profile.

        The user's email address.  # noqa: E501

        :param email: The email of this Profile.  # noqa: E501
        :type: str
        """
        if type(email) is Undefined:
            email = None
            self.nulls.discard("email")
        elif email is None:
            self.nulls.add("email")
        else:
            self.nulls.discard("email")
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 128):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 1):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `1`")  # noqa: E501

        self._email = email

    @property
    def avatar_url(self):
        """Gets the avatar_url of this Profile.  # noqa: E501

        The user's avatar.  # noqa: E501

        :return: The avatar_url of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this Profile.

        The user's avatar.  # noqa: E501

        :param avatar_url: The avatar_url of this Profile.  # noqa: E501
        :type: str
        """
        if type(avatar_url) is Undefined:
            avatar_url = None
            self.nulls.discard("avatar_url")
        elif avatar_url is None:
            self.nulls.add("avatar_url")
        else:
            self.nulls.discard("avatar_url")
        if (self.local_vars_configuration.client_side_validation and
                avatar_url is not None and len(avatar_url) > 2048):
            raise ValueError("Invalid value for `avatar_url`, length must be less than or equal to `2048`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                avatar_url is not None and len(avatar_url) < 1):
            raise ValueError("Invalid value for `avatar_url`, length must be greater than or equal to `1`")  # noqa: E501

        self._avatar_url = avatar_url

    @property
    def locale(self):
        """Gets the locale of this Profile.  # noqa: E501

        End-user's locale information in BCP 47 format.  # noqa: E501

        :return: The locale of this Profile.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this Profile.

        End-user's locale information in BCP 47 format.  # noqa: E501

        :param locale: The locale of this Profile.  # noqa: E501
        :type: str
        """
        if type(locale) is Undefined:
            locale = None
            self.nulls.discard("locale")
        elif locale is None:
            self.nulls.add("locale")
        else:
            self.nulls.discard("locale")
        if (self.local_vars_configuration.client_side_validation and
                locale is not None and len(locale) > 64):
            raise ValueError("Invalid value for `locale`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                locale is not None and len(locale) < 1):
            raise ValueError("Invalid value for `locale`, length must be greater than or equal to `1`")  # noqa: E501

        self._locale = locale

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Profile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Profile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined

try:
    Integration = __import__("sunshine_conversations_client.model."+re.sub(r'(?<!^)(?=[A-Z])', '_', "Integration").lower(), fromlist=("Integration")).Integration
except ImportError:
    pass

class Twilio(Integration):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'account_sid': 'str',
        'auth_token': 'str',
        'phone_number_sid': 'str',
        'messaging_service_sid': 'str',
        'default_responder_id': 'str',
        'default_responder': 'DefaultResponderDefaultResponder'
    }

    attribute_map = {
        'type': 'type',
        'account_sid': 'accountSid',
        'auth_token': 'authToken',
        'phone_number_sid': 'phoneNumberSid',
        'messaging_service_sid': 'messagingServiceSid',
        'default_responder_id': 'defaultResponderId',
        'default_responder': 'defaultResponder'
    }

    nulls = set()

    def __init__(self, type='twilio', account_sid=None, auth_token=None, phone_number_sid=None, messaging_service_sid=None, default_responder_id=Undefined(), default_responder=None, local_vars_configuration=None, **kwargs):  # noqa: E501
        """Twilio - a model defined in OpenAPI"""  # noqa: E501
        super().__init__(**kwargs)

        if (super().openapi_types is not None):
            all_types = super().openapi_types.copy()
            all_types.update(self.openapi_types)
            self.openapi_types = all_types

        if (super().attribute_map is not None):
            all_attributes = super().attribute_map.copy()
            all_attributes.update(self.attribute_map)
            self.attribute_map = all_attributes
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._account_sid = None
        self._auth_token = None
        self._phone_number_sid = None
        self._messaging_service_sid = None
        self._default_responder_id = None
        self._default_responder = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.account_sid = account_sid
        if auth_token is not None:
            self.auth_token = auth_token
        if phone_number_sid is not None:
            self.phone_number_sid = phone_number_sid
        if messaging_service_sid is not None:
            self.messaging_service_sid = messaging_service_sid
        self.default_responder_id = default_responder_id
        if default_responder is not None:
            self.default_responder = default_responder

    @property
    def type(self):
        """Gets the type of this Twilio.  # noqa: E501

        To configure a Twilio integration, acquire the required information from the user and call the Create Integration endpoint.   # noqa: E501

        :return: The type of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Twilio.

        To configure a Twilio integration, acquire the required information from the user and call the Create Integration endpoint.   # noqa: E501

        :param type: The type of this Twilio.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def account_sid(self):
        """Gets the account_sid of this Twilio.  # noqa: E501

        Twilio Account SID.  # noqa: E501

        :return: The account_sid of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._account_sid

    @account_sid.setter
    def account_sid(self, account_sid):
        """Sets the account_sid of this Twilio.

        Twilio Account SID.  # noqa: E501

        :param account_sid: The account_sid of this Twilio.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_sid is None:  # noqa: E501
            raise ValueError("Invalid value for `account_sid`, must not be `None`")  # noqa: E501

        self._account_sid = account_sid

    @property
    def auth_token(self):
        """Gets the auth_token of this Twilio.  # noqa: E501

        Twilio Auth Token.  # noqa: E501

        :return: The auth_token of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token):
        """Sets the auth_token of this Twilio.

        Twilio Auth Token.  # noqa: E501

        :param auth_token: The auth_token of this Twilio.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and auth_token is None:  # noqa: E501
            raise ValueError("Invalid value for `auth_token`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                auth_token is not None and len(auth_token) < 1):
            raise ValueError("Invalid value for `auth_token`, length must be greater than or equal to `1`")  # noqa: E501

        self._auth_token = auth_token

    @property
    def phone_number_sid(self):
        """Gets the phone_number_sid of this Twilio.  # noqa: E501

        SID for specific phone number. One of `messagingServiceSid` or `phoneNumberSid` must be provided when creating a Twilio integration.  # noqa: E501

        :return: The phone_number_sid of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_sid

    @phone_number_sid.setter
    def phone_number_sid(self, phone_number_sid):
        """Sets the phone_number_sid of this Twilio.

        SID for specific phone number. One of `messagingServiceSid` or `phoneNumberSid` must be provided when creating a Twilio integration.  # noqa: E501

        :param phone_number_sid: The phone_number_sid of this Twilio.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone_number_sid is not None and len(phone_number_sid) < 1):
            raise ValueError("Invalid value for `phone_number_sid`, length must be greater than or equal to `1`")  # noqa: E501

        self._phone_number_sid = phone_number_sid

    @property
    def messaging_service_sid(self):
        """Gets the messaging_service_sid of this Twilio.  # noqa: E501

        SID for specific messaging service. One of `messagingServiceSid` or `phoneNumberSid` must be provided when creating a Twilio integration.  # noqa: E501

        :return: The messaging_service_sid of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._messaging_service_sid

    @messaging_service_sid.setter
    def messaging_service_sid(self, messaging_service_sid):
        """Sets the messaging_service_sid of this Twilio.

        SID for specific messaging service. One of `messagingServiceSid` or `phoneNumberSid` must be provided when creating a Twilio integration.  # noqa: E501

        :param messaging_service_sid: The messaging_service_sid of this Twilio.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                messaging_service_sid is not None and len(messaging_service_sid) < 1):
            raise ValueError("Invalid value for `messaging_service_sid`, length must be greater than or equal to `1`")  # noqa: E501

        self._messaging_service_sid = messaging_service_sid

    @property
    def default_responder_id(self):
        """Gets the default_responder_id of this Twilio.  # noqa: E501

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :return: The default_responder_id of this Twilio.  # noqa: E501
        :rtype: str
        """
        return self._default_responder_id

    @default_responder_id.setter
    def default_responder_id(self, default_responder_id):
        """Sets the default_responder_id of this Twilio.

        The default responder ID for the integration. This is the ID of the responder that will be used to send messages to the user. For more information, refer to <a href=\"https://docs.smooch.io/guide/switchboard/#per-channel-default-responder\">Per-channel default responder</a> guide.   # noqa: E501

        :param default_responder_id: The default_responder_id of this Twilio.  # noqa: E501
        :type: str
        """
        if type(default_responder_id) is Undefined:
            default_responder_id = None
            self.nulls.discard("default_responder_id")
        elif default_responder_id is None:
            self.nulls.add("default_responder_id")
        else:
            self.nulls.discard("default_responder_id")

        self._default_responder_id = default_responder_id

    @property
    def default_responder(self):
        """Gets the default_responder of this Twilio.  # noqa: E501


        :return: The default_responder of this Twilio.  # noqa: E501
        :rtype: DefaultResponderDefaultResponder
        """
        return self._default_responder

    @default_responder.setter
    def default_responder(self, default_responder):
        """Sets the default_responder of this Twilio.


        :param default_responder: The default_responder of this Twilio.  # noqa: E501
        :type: DefaultResponderDefaultResponder
        """

        self._default_responder = default_responder

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Twilio):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Twilio):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class UserMergeEventAllOfPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'merged_users': 'UserMergeEventAllOfPayloadMergedUsers',
        'merged_conversations': 'UserMergeEventAllOfPayloadMergedConversations',
        'merged_clients': 'UserMergeEventAllOfPayloadMergedClients',
        'discarded_metadata': 'object',
        'reason': 'str'
    }

    attribute_map = {
        'merged_users': 'mergedUsers',
        'merged_conversations': 'mergedConversations',
        'merged_clients': 'mergedClients',
        'discarded_metadata': 'discardedMetadata',
        'reason': 'reason'
    }

    nulls = set()

    def __init__(self, merged_users=None, merged_conversations=Undefined(), merged_clients=Undefined(), discarded_metadata=Undefined(), reason=None, local_vars_configuration=None):  # noqa: E501
        """UserMergeEventAllOfPayload - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._merged_users = None
        self._merged_conversations = None
        self._merged_clients = None
        self._discarded_metadata = None
        self._reason = None
        self.discriminator = None

        if merged_users is not None:
            self.merged_users = merged_users
        self.merged_conversations = merged_conversations
        self.merged_clients = merged_clients
        self.discarded_metadata = discarded_metadata
        if reason is not None:
            self.reason = reason

    @property
    def merged_users(self):
        """Gets the merged_users of this UserMergeEventAllOfPayload.  # noqa: E501


        :return: The merged_users of this UserMergeEventAllOfPayload.  # noqa: E501
        :rtype: UserMergeEventAllOfPayloadMergedUsers
        """
        return self._merged_users

    @merged_users.setter
    def merged_users(self, merged_users):
        """Sets the merged_users of this UserMergeEventAllOfPayload.


        :param merged_users: The merged_users of this UserMergeEventAllOfPayload.  # noqa: E501
        :type: UserMergeEventAllOfPayloadMergedUsers
        """

        self._merged_users = merged_users

    @property
    def merged_conversations(self):
        """Gets the merged_conversations of this UserMergeEventAllOfPayload.  # noqa: E501


        :return: The merged_conversations of this UserMergeEventAllOfPayload.  # noqa: E501
        :rtype: UserMergeEventAllOfPayloadMergedConversations
        """
        return self._merged_conversations

    @merged_conversations.setter
    def merged_conversations(self, merged_conversations):
        """Sets the merged_conversations of this UserMergeEventAllOfPayload.


        :param merged_conversations: The merged_conversations of this UserMergeEventAllOfPayload.  # noqa: E501
        :type: UserMergeEventAllOfPayloadMergedConversations
        """
        if type(merged_conversations) is Undefined:
            merged_conversations = None
            self.nulls.discard("merged_conversations")
        elif merged_conversations is None:
            self.nulls.add("merged_conversations")
        else:
            self.nulls.discard("merged_conversations")

        self._merged_conversations = merged_conversations

    @property
    def merged_clients(self):
        """Gets the merged_clients of this UserMergeEventAllOfPayload.  # noqa: E501


        :return: The merged_clients of this UserMergeEventAllOfPayload.  # noqa: E501
        :rtype: UserMergeEventAllOfPayloadMergedClients
        """
        return self._merged_clients

    @merged_clients.setter
    def merged_clients(self, merged_clients):
        """Sets the merged_clients of this UserMergeEventAllOfPayload.


        :param merged_clients: The merged_clients of this UserMergeEventAllOfPayload.  # noqa: E501
        :type: UserMergeEventAllOfPayloadMergedClients
        """
        if type(merged_clients) is Undefined:
            merged_clients = None
            self.nulls.discard("merged_clients")
        elif merged_clients is None:
            self.nulls.add("merged_clients")
        else:
            self.nulls.discard("merged_clients")

        self._merged_clients = merged_clients

    @property
    def discarded_metadata(self):
        """Gets the discarded_metadata of this UserMergeEventAllOfPayload.  # noqa: E501

        A flat object with the set of metadata properties that were discarded when merging the two users. This should contain values only if the combined metadata fields exceed the 4KB limit.  # noqa: E501

        :return: The discarded_metadata of this UserMergeEventAllOfPayload.  # noqa: E501
        :rtype: object
        """
        return self._discarded_metadata

    @discarded_metadata.setter
    def discarded_metadata(self, discarded_metadata):
        """Sets the discarded_metadata of this UserMergeEventAllOfPayload.

        A flat object with the set of metadata properties that were discarded when merging the two users. This should contain values only if the combined metadata fields exceed the 4KB limit.  # noqa: E501

        :param discarded_metadata: The discarded_metadata of this UserMergeEventAllOfPayload.  # noqa: E501
        :type: object
        """
        if type(discarded_metadata) is Undefined:
            discarded_metadata = None
            self.nulls.discard("discarded_metadata")
        elif discarded_metadata is None:
            self.nulls.add("discarded_metadata")
        else:
            self.nulls.discard("discarded_metadata")

        self._discarded_metadata = discarded_metadata

    @property
    def reason(self):
        """Gets the reason of this UserMergeEventAllOfPayload.  # noqa: E501

        The reason for which the users merged. * `api` - The users were merged using the API. * `channelLinking` - The users were merged as a result of initiating a channel link. * `sdkLogin` - The users were merged as a result of logging into an SDK device.   # noqa: E501

        :return: The reason of this UserMergeEventAllOfPayload.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this UserMergeEventAllOfPayload.

        The reason for which the users merged. * `api` - The users were merged using the API. * `channelLinking` - The users were merged as a result of initiating a channel link. * `sdkLogin` - The users were merged as a result of logging into an SDK device.   # noqa: E501

        :param reason: The reason of this UserMergeEventAllOfPayload.  # noqa: E501
        :type: str
        """
        allowed_values = ["api", "channelLinking", "sdkLogin"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and reason not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `reason` ({0}), must be one of {1}"  # noqa: E501
                .format(reason, allowed_values)
            )

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserMergeEventAllOfPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserMergeEventAllOfPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class MessageWebhook(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'received': 'str',
        'author': 'AuthorWebhook',
        'content': 'Content',
        'source': 'Source',
        'quoted_message': 'QuotedMessage',
        'metadata': 'object',
        'deleted': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'received': 'received',
        'author': 'author',
        'content': 'content',
        'source': 'source',
        'quoted_message': 'quotedMessage',
        'metadata': 'metadata',
        'deleted': 'deleted'
    }

    nulls = set()

    def __init__(self, id=None, received=None, author=None, content=None, source=None, quoted_message=Undefined(), metadata=Undefined(), deleted=Undefined(), local_vars_configuration=None):  # noqa: E501
        """MessageWebhook - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._received = None
        self._author = None
        self._content = None
        self._source = None
        self._quoted_message = None
        self._metadata = None
        self._deleted = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if received is not None:
            self.received = received
        if author is not None:
            self.author = author
        if content is not None:
            self.content = content
        if source is not None:
            self.source = source
        self.quoted_message = quoted_message
        self.metadata = metadata
        self.deleted = deleted

    @property
    def id(self):
        """Gets the id of this MessageWebhook.  # noqa: E501

        The unique ID of the message.  # noqa: E501

        :return: The id of this MessageWebhook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageWebhook.

        The unique ID of the message.  # noqa: E501

        :param id: The id of this MessageWebhook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def received(self):
        """Gets the received of this MessageWebhook.  # noqa: E501

        A datetime string with the format `YYYY-MM-DDThh:mm:ss.SSSZ` representing when Sunshine Conversations received the message.  # noqa: E501

        :return: The received of this MessageWebhook.  # noqa: E501
        :rtype: str
        """
        return self._received

    @received.setter
    def received(self, received):
        """Sets the received of this MessageWebhook.

        A datetime string with the format `YYYY-MM-DDThh:mm:ss.SSSZ` representing when Sunshine Conversations received the message.  # noqa: E501

        :param received: The received of this MessageWebhook.  # noqa: E501
        :type: str
        """

        self._received = received

    @property
    def author(self):
        """Gets the author of this MessageWebhook.  # noqa: E501


        :return: The author of this MessageWebhook.  # noqa: E501
        :rtype: AuthorWebhook
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this MessageWebhook.


        :param author: The author of this MessageWebhook.  # noqa: E501
        :type: AuthorWebhook
        """

        self._author = author

    @property
    def content(self):
        """Gets the content of this MessageWebhook.  # noqa: E501

        The content of the message.  # noqa: E501

        :return: The content of this MessageWebhook.  # noqa: E501
        :rtype: Content
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this MessageWebhook.

        The content of the message.  # noqa: E501

        :param content: The content of this MessageWebhook.  # noqa: E501
        :type: Content
        """

        self._content = content

    @property
    def source(self):
        """Gets the source of this MessageWebhook.  # noqa: E501


        :return: The source of this MessageWebhook.  # noqa: E501
        :rtype: Source
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this MessageWebhook.


        :param source: The source of this MessageWebhook.  # noqa: E501
        :type: Source
        """

        self._source = source

    @property
    def quoted_message(self):
        """Gets the quoted_message of this MessageWebhook.  # noqa: E501

        The quoted message is currently only available for WhatsApp and Web Messenger `formResponse` messages.  # noqa: E501

        :return: The quoted_message of this MessageWebhook.  # noqa: E501
        :rtype: QuotedMessage
        """
        return self._quoted_message

    @quoted_message.setter
    def quoted_message(self, quoted_message):
        """Sets the quoted_message of this MessageWebhook.

        The quoted message is currently only available for WhatsApp and Web Messenger `formResponse` messages.  # noqa: E501

        :param quoted_message: The quoted_message of this MessageWebhook.  # noqa: E501
        :type: QuotedMessage
        """
        if type(quoted_message) is Undefined:
            quoted_message = None
            self.nulls.discard("quoted_message")
        elif quoted_message is None:
            self.nulls.add("quoted_message")
        else:
            self.nulls.discard("quoted_message")

        self._quoted_message = quoted_message

    @property
    def metadata(self):
        """Gets the metadata of this MessageWebhook.  # noqa: E501


        :return: The metadata of this MessageWebhook.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this MessageWebhook.


        :param metadata: The metadata of this MessageWebhook.  # noqa: E501
        :type: object
        """
        if type(metadata) is Undefined:
            metadata = None
            self.nulls.discard("metadata")
        elif metadata is None:
            self.nulls.add("metadata")
        else:
            self.nulls.discard("metadata")

        self._metadata = metadata

    @property
    def deleted(self):
        """Gets the deleted of this MessageWebhook.  # noqa: E501

        true if the message serves as a placeholder for one that has been deleted.  # noqa: E501

        :return: The deleted of this MessageWebhook.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this MessageWebhook.

        true if the message serves as a placeholder for one that has been deleted.  # noqa: E501

        :param deleted: The deleted of this MessageWebhook.  # noqa: E501
        :type: bool
        """
        if type(deleted) is Undefined:
            deleted = None
            self.nulls.discard("deleted")
        elif deleted is None:
            self.nulls.add("deleted")
        else:
            self.nulls.discard("deleted")

        self._deleted = deleted

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageWebhook):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessageWebhook):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class MessagePost(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'author': 'Author',
        'content': 'Content',
        'destination': 'Destination',
        'metadata': 'object',
        'override': 'MessageOverride',
        'schema': 'str'
    }

    attribute_map = {
        'author': 'author',
        'content': 'content',
        'destination': 'destination',
        'metadata': 'metadata',
        'override': 'override',
        'schema': 'schema'
    }

    nulls = set()

    def __init__(self, author=None, content=None, destination=None, metadata=Undefined(), override=None, schema=None, local_vars_configuration=None):  # noqa: E501
        """MessagePost - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._author = None
        self._content = None
        self._destination = None
        self._metadata = None
        self._override = None
        self._schema = None
        self.discriminator = None

        self.author = author
        self.content = content
        if destination is not None:
            self.destination = destination
        self.metadata = metadata
        if override is not None:
            self.override = override
        if schema is not None:
            self.schema = schema

    @property
    def author(self):
        """Gets the author of this MessagePost.  # noqa: E501

        The author of the message.  # noqa: E501

        :return: The author of this MessagePost.  # noqa: E501
        :rtype: Author
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this MessagePost.

        The author of the message.  # noqa: E501

        :param author: The author of this MessagePost.  # noqa: E501
        :type: Author
        """
        if self.local_vars_configuration.client_side_validation and author is None:  # noqa: E501
            raise ValueError("Invalid value for `author`, must not be `None`")  # noqa: E501

        self._author = author

    @property
    def content(self):
        """Gets the content of this MessagePost.  # noqa: E501

        The content of the message.  # noqa: E501

        :return: The content of this MessagePost.  # noqa: E501
        :rtype: Content
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this MessagePost.

        The content of the message.  # noqa: E501

        :param content: The content of this MessagePost.  # noqa: E501
        :type: Content
        """
        if self.local_vars_configuration.client_side_validation and content is None:  # noqa: E501
            raise ValueError("Invalid value for `content`, must not be `None`")  # noqa: E501

        self._content = content

    @property
    def destination(self):
        """Gets the destination of this MessagePost.  # noqa: E501


        :return: The destination of this MessagePost.  # noqa: E501
        :rtype: Destination
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this MessagePost.


        :param destination: The destination of this MessagePost.  # noqa: E501
        :type: Destination
        """

        self._destination = destination

    @property
    def metadata(self):
        """Gets the metadata of this MessagePost.  # noqa: E501

        Flat object containing custom properties. Strings, numbers and booleans  are the only supported format that can be passed to metadata. The metadata is limited to 4KB in size.   # noqa: E501

        :return: The metadata of this MessagePost.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this MessagePost.

        Flat object containing custom properties. Strings, numbers and booleans  are the only supported format that can be passed to metadata. The metadata is limited to 4KB in size.   # noqa: E501

        :param metadata: The metadata of this MessagePost.  # noqa: E501
        :type: object
        """
        if type(metadata) is Undefined:
            metadata = None
            self.nulls.discard("metadata")
        elif metadata is None:
            self.nulls.add("metadata")
        else:
            self.nulls.discard("metadata")

        self._metadata = metadata

    @property
    def override(self):
        """Gets the override of this MessagePost.  # noqa: E501


        :return: The override of this MessagePost.  # noqa: E501
        :rtype: MessageOverride
        """
        return self._override

    @override.setter
    def override(self, override):
        """Sets the override of this MessagePost.


        :param override: The override of this MessagePost.  # noqa: E501
        :type: MessageOverride
        """

        self._override = override

    @property
    def schema(self):
        """Gets the schema of this MessagePost.  # noqa: E501

        When `schema` is set to `\"whatsapp\"`, the `content` key is expected to conform to the [native WhatsApp schema](https://developers.facebook.com/docs/whatsapp/api/messages/message-templates) for sending message templates. For more details, consult the documentation for [sending message templates on WhatsApp](https://docs.smooch.io/guide/whatsapp/#sending-message-templates).   # noqa: E501

        :return: The schema of this MessagePost.  # noqa: E501
        :rtype: str
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this MessagePost.

        When `schema` is set to `\"whatsapp\"`, the `content` key is expected to conform to the [native WhatsApp schema](https://developers.facebook.com/docs/whatsapp/api/messages/message-templates) for sending message templates. For more details, consult the documentation for [sending message templates on WhatsApp](https://docs.smooch.io/guide/whatsapp/#sending-message-templates).   # noqa: E501

        :param schema: The schema of this MessagePost.  # noqa: E501
        :type: str
        """

        self._schema = schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessagePost):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MessagePost):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Sunshine Conversations API

    The version of the OpenAPI document: 14.3.4
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


from sunshine_conversations_client.configuration import Configuration
from sunshine_conversations_client.undefined import Undefined


class FormResponseMessageField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'name': 'str',
        'label': 'str',
        'text': 'str',
        'email': 'str',
        'select': 'list[object]',
        'quoted_message_id': 'str'
    }

    attribute_map = {
        'type': 'type',
        'name': 'name',
        'label': 'label',
        'text': 'text',
        'email': 'email',
        'select': 'select',
        'quoted_message_id': 'quotedMessageId'
    }

    nulls = set()

    def __init__(self, type=None, name=None, label=None, text=None, email=None, select=None, quoted_message_id=None, local_vars_configuration=None):  # noqa: E501
        """FormResponseMessageField - a model defined in OpenAPI"""  # noqa: E501
        
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._name = None
        self._label = None
        self._text = None
        self._email = None
        self._select = None
        self._quoted_message_id = None
        self.discriminator = None

        self.type = type
        self.name = name
        self.label = label
        if text is not None:
            self.text = text
        if email is not None:
            self.email = email
        if select is not None:
            self.select = select
        if quoted_message_id is not None:
            self.quoted_message_id = quoted_message_id

    @property
    def type(self):
        """Gets the type of this FormResponseMessageField.  # noqa: E501

        The field type.  # noqa: E501

        :return: The type of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FormResponseMessageField.

        The field type.  # noqa: E501

        :param type: The type of this FormResponseMessageField.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["email", "select", "text"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def name(self):
        """Gets the name of this FormResponseMessageField.  # noqa: E501

        The name of the field. Must be unique per form or formResponse.  # noqa: E501

        :return: The name of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FormResponseMessageField.

        The name of the field. Must be unique per form or formResponse.  # noqa: E501

        :param name: The name of this FormResponseMessageField.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 128):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def label(self):
        """Gets the label of this FormResponseMessageField.  # noqa: E501

        The label of the field. What the field is displayed as on Web Messenger.  # noqa: E501

        :return: The label of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this FormResponseMessageField.

        The label of the field. What the field is displayed as on Web Messenger.  # noqa: E501

        :param label: The label of this FormResponseMessageField.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) > 128):
            raise ValueError("Invalid value for `label`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                label is not None and len(label) < 1):
            raise ValueError("Invalid value for `label`, length must be greater than or equal to `1`")  # noqa: E501

        self._label = label

    @property
    def text(self):
        """Gets the text of this FormResponseMessageField.  # noqa: E501

        Specifies the response for a text field.  # noqa: E501

        :return: The text of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this FormResponseMessageField.

        Specifies the response for a text field.  # noqa: E501

        :param text: The text of this FormResponseMessageField.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                text is not None and len(text) > 256):
            raise ValueError("Invalid value for `text`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                text is not None and len(text) < 1):
            raise ValueError("Invalid value for `text`, length must be greater than or equal to `1`")  # noqa: E501

        self._text = text

    @property
    def email(self):
        """Gets the email of this FormResponseMessageField.  # noqa: E501

        Specifies the response for a email field.  # noqa: E501

        :return: The email of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this FormResponseMessageField.

        Specifies the response for a email field.  # noqa: E501

        :param email: The email of this FormResponseMessageField.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) > 128):
            raise ValueError("Invalid value for `email`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                email is not None and len(email) < 1):
            raise ValueError("Invalid value for `email`, length must be greater than or equal to `1`")  # noqa: E501

        self._email = email

    @property
    def select(self):
        """Gets the select of this FormResponseMessageField.  # noqa: E501

        Array of objects representing the response for a field of type select. Form and formResponse messages only.  # noqa: E501

        :return: The select of this FormResponseMessageField.  # noqa: E501
        :rtype: list[object]
        """
        return self._select

    @select.setter
    def select(self, select):
        """Sets the select of this FormResponseMessageField.

        Array of objects representing the response for a field of type select. Form and formResponse messages only.  # noqa: E501

        :param select: The select of this FormResponseMessageField.  # noqa: E501
        :type: list[object]
        """

        self._select = select

    @property
    def quoted_message_id(self):
        """Gets the quoted_message_id of this FormResponseMessageField.  # noqa: E501

        The messageId for the form that this response belongs to.  # noqa: E501

        :return: The quoted_message_id of this FormResponseMessageField.  # noqa: E501
        :rtype: str
        """
        return self._quoted_message_id

    @quoted_message_id.setter
    def quoted_message_id(self, quoted_message_id):
        """Sets the quoted_message_id of this FormResponseMessageField.

        The messageId for the form that this response belongs to.  # noqa: E501

        :param quoted_message_id: The quoted_message_id of this FormResponseMessageField.  # noqa: E501
        :type: str
        """

        self._quoted_message_id = quoted_message_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormResponseMessageField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FormResponseMessageField):
            return True

        return self.to_dict() != other.to_dict()
